@@ -365,6 +365,14 @@ niftyreg.nonlinear <- function (source, target, init = NULL, sourceMask = NULL,
 }
 
 
+#' @rdname niftyreg
+#' @export
+asNifti.niftyreg <- function (x, ...)
+{
+    return (x$image)
+}
+
+
 #' @rdname niftyreg
 #' @export
 as.array.niftyreg <- function (x, ...)
